.. django-flexisettings documentation master file, created by
   sphinx-quickstart on Thu Apr 11 17:39:25 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-flexisettings
===============================

.. include only the intro part of README file
.. include:: ../README.rst
   :start-line: 4
   :end-line: 12


Documentation
-------------

.. toctree::
   :maxdepth: 2

   install
   settings
   internals
   security
   debugging
   license


References
----------

* `Django project <https://www.djangoproject.com/>`_
* `Django settings <https://docs.djangoproject.com/en/dev/topics/settings/>`_
* `Splitting up the settings file <https://code.djangoproject.com/wiki/SplitSettings>`_
* `PyPI django-flexisettings <https://pypi.python.org/pypi/django-flexisettings>`_


Project layouts
---------------

* `Django Project Conventions, Revisited <http://zacharyvoase.com/2010/02/03/django-project-conventions/>`_ (Zachary Voase)
* `django-resusable-app <http://django-reusable-app-docs.readthedocs.org/en/latest/index.html>`_
* `pinax-project-zero <https://github.com/pinax/pinax-project-zero>`_
* `Django Project Structure <http://www.deploydjango.com/django_project_structure/>`_
* `A general django project structure or folder layout <http://timmyomahony.com/blog/2012/11/09/general-django-project-structure-or-folder-layout/>`_


Search
======

* :ref:`search`

